==> huaweicloudsdkdrs-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/show_object_mapping_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowObjectMappingResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'object_mapping_list': 'list[DbObjectInfo]'
    }

    attribute_map = {
        'count': 'count',
        'object_mapping_list': 'object_mapping_list'
    }

    def __init__(self, count=None, object_mapping_list=None):
        """ShowObjectMappingResponse

        The model defined in huaweicloud sdk

        :param count: 总数。
        :type count: int
        :param object_mapping_list: 同步映射数据列表。
        :type object_mapping_list: list[:class:`huaweicloudsdkdrs.v5.DbObjectInfo`]
        """
        
        super(ShowObjectMappingResponse, self).__init__()

        self._count = None
        self._object_mapping_list = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if object_mapping_list is not None:
            self.object_mapping_list = object_mapping_list

    @property
    def count(self):
        """Gets the count of this ShowObjectMappingResponse.

        总数。

        :return: The count of this ShowObjectMappingResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ShowObjectMappingResponse.

        总数。

        :param count: The count of this ShowObjectMappingResponse.
        :type count: int
        """
        self._count = count

    @property
    def object_mapping_list(self):
        """Gets the object_mapping_list of this ShowObjectMappingResponse.

        同步映射数据列表。

        :return: The object_mapping_list of this ShowObjectMappingResponse.
        :rtype: list[:class:`huaweicloudsdkdrs.v5.DbObjectInfo`]
        """
        return self._object_mapping_list

    @object_mapping_list.setter
    def object_mapping_list(self, object_mapping_list):
        """Sets the object_mapping_list of this ShowObjectMappingResponse.

        同步映射数据列表。

        :param object_mapping_list: The object_mapping_list of this ShowObjectMappingResponse.
        :type object_mapping_list: list[:class:`huaweicloudsdkdrs.v5.DbObjectInfo`]
        """
        self._object_mapping_list = object_mapping_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowObjectMappingResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.146-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/show_object_mapping_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowObjectMappingResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'object_mapping_list': 'list[DbObjectInfo]'
    }

    attribute_map = {
        'count': 'count',
        'object_mapping_list': 'object_mapping_list'
    }

    def __init__(self, count=None, object_mapping_list=None):
        r"""ShowObjectMappingResponse

        The model defined in huaweicloud sdk

        :param count: 总数。
        :type count: int
        :param object_mapping_list: 同步映射数据列表。
        :type object_mapping_list: list[:class:`huaweicloudsdkdrs.v5.DbObjectInfo`]
        """
        
        super(ShowObjectMappingResponse, self).__init__()

        self._count = None
        self._object_mapping_list = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if object_mapping_list is not None:
            self.object_mapping_list = object_mapping_list

    @property
    def count(self):
        r"""Gets the count of this ShowObjectMappingResponse.

        总数。

        :return: The count of this ShowObjectMappingResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ShowObjectMappingResponse.

        总数。

        :param count: The count of this ShowObjectMappingResponse.
        :type count: int
        """
        self._count = count

    @property
    def object_mapping_list(self):
        r"""Gets the object_mapping_list of this ShowObjectMappingResponse.

        同步映射数据列表。

        :return: The object_mapping_list of this ShowObjectMappingResponse.
        :rtype: list[:class:`huaweicloudsdkdrs.v5.DbObjectInfo`]
        """
        return self._object_mapping_list

    @object_mapping_list.setter
    def object_mapping_list(self, object_mapping_list):
        r"""Sets the object_mapping_list of this ShowObjectMappingResponse.

        同步映射数据列表。

        :param object_mapping_list: The object_mapping_list of this ShowObjectMappingResponse.
        :type object_mapping_list: list[:class:`huaweicloudsdkdrs.v5.DbObjectInfo`]
        """
        self._object_mapping_list = object_mapping_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowObjectMappingResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
